@@ -6,8 +6,8 @@ import numpy as np
 import pandas
 
 pandas.options.mode.chained_assignment = None
-from .accessory import pdag2dag, to_bnlearn, g_test, z_test, find_causes, pairwise, dag2cpdag, \
-    independence_test, orient_v_structure, orient_propagation
+from .accessory import g_test, z_test, find_causes, pairwise, dag2cpdag, independence_test, orient_v_structure, \
+    orient_propagation
 from .score import local_score
 
 
@@ -64,7 +64,7 @@ def check_cycle(vi, vj, dag):
     return cyc_flag
 
 
-def hc(data, method='standard', score_function='default', debug=False):
+def hc(data, method='standard', score_function='default', alpha=0.3, debug=False):
     '''
         :param data: the training data used for learn BN
         :param method: the method for dealing with missing values, including:
@@ -153,7 +153,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         if W not in cache_score[vj][par_cur]:
                             cols = [varnames.index(vj)] + [varnames.index(x) for x in varnames if x in par_cur]
                             cache_score[vj][par_cur][W] = local_score(cache_data[W], cols, score_function,
-                                                                      cache_weight[W])
+                                                                      cache_weight[W], alpha=alpha)
                         # compute the local score for the searching graph
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache_score[vj]:
@@ -161,7 +161,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         if W not in cache_score[vj][par_sea]:
                             cols = [varnames.index(vj)] + [varnames.index(x) for x in varnames if x in par_sea]
                             cache_score[vj][par_sea][W] = local_score(cache_data[W], cols, score_function,
-                                                                      cache_weight[W])
+                                                                      cache_weight[W], alpha=alpha)
                         if cache_score[vj][par_sea][W] != np.nan:
                             diff_temp = cache_score[vj][par_sea][W] - cache_score[vj][par_cur][W]
                             if debug:
@@ -200,14 +200,14 @@ def hc(data, method='standard', score_function='default', debug=False):
                             cols = [varnames.index(par_vi)] + [varnames.index(x) for x in varnames if
                                                                x in par_cur_par_vi]
                             cache_score[par_vi][par_cur_par_vi][W] = local_score(cache_data[W], cols, score_function,
-                                                                                 cache_weight[W])
+                                                                                 cache_weight[W], alpha=alpha)
                         par_cur_vi = tuple(dag[vi]['par'])
                         if par_cur_vi not in cache_score[vi]:
                             cache_score[vi][par_cur_vi] = {}
                         if W not in cache_score[vi][par_cur_vi]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_cur_vi]
                             cache_score[vi][par_cur_vi][W] = local_score(cache_data[W], cols, score_function,
-                                                                         cache_weight[W])
+                                                                         cache_weight[W], alpha=alpha)
                         # compute the local score for the searching graph
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache_score[par_vi]:
@@ -216,14 +216,15 @@ def hc(data, method='standard', score_function='default', debug=False):
                             cols = [varnames.index(par_vi)] + [varnames.index(x) for x in varnames if
                                                                x in par_sea_par_vi]
                             cache_score[par_vi][par_sea_par_vi][W] = local_score(cache_data[W], cols,
-                                                                                 score_function, cache_weight[W])
+                                                                                 score_function, cache_weight[W],
+                                                                                 alpha=alpha)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache_score[vi]:
                             cache_score[vi][par_sea_vi] = {}
                         if W not in cache_score[vi][par_sea_vi]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_sea_vi]
                             cache_score[vi][par_sea_vi][W] = local_score(cache_data[W], cols, score_function,
-                                                                         cache_weight[W])
+                                                                         cache_weight[W], alpha=alpha)
                         if cache_score[vi][par_cur_vi][W] != np.nan and cache_score[par_vi][par_sea_par_vi][
                             W] != np.nan:
                             diff_temp = cache_score[vi][par_sea_vi][W] + cache_score[par_vi][par_sea_par_vi][W] - \
@@ -256,7 +257,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         if W not in cache_score[vi][par_cur]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_cur]
                             cache_score[vi][par_cur][W] = local_score(cache_data[W], cols, score_function,
-                                                                      cache_weight[W])
+                                                                      cache_weight[W], alpha=alpha)
                         # compute the local score for the searching graph
                         par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea not in cache_score[vi]:
@@ -264,7 +265,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         if W not in cache_score[vi][par_sea]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_sea]
                             cache_score[vi][par_sea][W] = local_score(cache_data[W], cols, score_function,
-                                                                      cache_weight[W])
+                                                                      cache_weight[W], alpha=alpha)
                         if cache_score[vi][par_cur][W] != np.nan:
                             diff_temp = cache_score[vi][par_sea][W] - cache_score[vi][par_cur][W]
                             if diff_temp - diff > 1e-10:
@@ -276,7 +277,8 @@ def hc(data, method='standard', score_function='default', debug=False):
                     else:
                         dag[vi]['par'] = sorted(dag[vi]['par'] + [par_vi])
             dag, candidate = dag_update(dag, edge_candidate, candidate, diff, debug)
-            cache_dag.append({var: {'par': [v for v in dag[var]['par']], 'nei': [v for v in dag[var]['nei']]} for var in dag})
+            cache_dag.append(
+                {var: {'par': [v for v in dag[var]['par']], 'nei': [v for v in dag[var]['nei']]} for var in dag})
         time_total = time.time() - time_total
         if debug:
             print('total cost: %.2f seconds' % time_total)
@@ -301,7 +303,8 @@ def hc(data, method='standard', score_function='default', debug=False):
             raise Exception('Mixed data is not supported.')
         # initialise dag, cached scores and candidate parents for each variable
         dag = {var: {'par': [], 'nei': []} for var in varnames}
-        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function)} for var in varnames}
+        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function, alpha=alpha)} for var in
+                 varnames}
         candidate = {var: [v for v in varnames if v is not var] for var in varnames}
         time_preprocess = time.time() - start_time
         diff = 1
@@ -321,7 +324,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache[vj]:
                             cols = [varnames.index(x) for x in (vj,) + par_sea]
-                            cache[vj][par_sea] = local_score(data, cols, score_function)
+                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[vj][par_sea] - cache[vj][tuple(dag[vj]['par'])]
                         if debug:
@@ -341,11 +344,11 @@ def hc(data, method='standard', score_function='default', debug=False):
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache[par_vi]:
                             cols = [varnames.index(x) for x in (par_vi,) + par_sea_par_vi]
-                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function)
+                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha=alpha)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache[vi]:
                             cols = [varnames.index(x) for x in (vi,) + par_sea_vi]
-                            cache[vi][par_sea_vi] = local_score(data, cols, score_function)
+                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[par_vi][par_sea_par_vi] + cache[vi][par_sea_vi] - cache[par_vi][
                             tuple(dag[par_vi]['par'])] - cache[vi][tuple(dag[vi]['par'])]
@@ -361,7 +364,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                     par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                     if par_sea not in cache[vi]:
                         cols = [varnames.index(x) for x in (vi,) + par_sea]
-                        cache[vi][par_sea] = local_score(data, cols, score_function)
+                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha=alpha)
                     time_score += time.time() - start_time
                     diff_temp = cache[vi][par_sea] - cache[vi][tuple(dag[vi]['par'])]
                     if diff_temp - diff > 1e-10:
@@ -450,7 +453,7 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
 #     return post_process(dag, dc)
 
 
-def ges(data, method='complete', score_function='default', prune=True, thres=0.1, debug=False):
+def ges(data, method='complete', score_function='default', prune=True, thres=0.1, alpha=0.3, debug=False):
     '''
     greedy equivalence search algorithm
     :param data: the training data used for learn BN
@@ -654,13 +657,13 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
                             if parents_new not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
                                 cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score_function,
-                                                                             weights=cache_weights[W])
+                                                                             weights=cache_weights[W], alpha=alpha)
                             score_new = cache_score[y][W][parents_new]
 
                             if parents_cur not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
                                 cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score_function,
-                                                                             weights=cache_weights[W])
+                                                                             weights=cache_weights[W], alpha=alpha)
                             score_cur = cache_score[y][W][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -708,12 +711,12 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
                             if parents_new not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
                                 cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score_function,
-                                                                             weights=cache_weights[W])
+                                                                             weights=cache_weights[W], alpha=alpha)
                             score_new = cache_score[y][W][parents_new]
                             if parents_cur not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
                                 cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score_function,
-                                                                             weights=cache_weights[W])
+                                                                             weights=cache_weights[W], alpha=alpha)
                             score_cur = cache_score[y][W][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -812,4 +815,4 @@ def dag_update(dag, edge_candidate, candidate, diff, debug):
             candidate[edge_candidate[1]].append(edge_candidate[0])
         if debug:
             print('best operation is:', edge_candidate, diff)
-    return dag, candidate
+    return dag, candidate
\ No newline at end of file
